import click
import json
import sys
from nomad_media_cli.helpers.get_id_from_url import get_id_from_url
from nomad_media_cli.helpers.utils import initialize_sdk

@click.command()
@click.option("--parent-id", help="The parent asset ID for the parent folder.")
@click.option("--url", help="The Nomad URL of the parent asset folder (bucket::object-key).")
@click.option("--object-key", help="The Nomad Object-key of the parent asset folder. This option assumes the default bucket that was previously set with the `set-bucket` command.")
@click.option("--display-name", required=True, help="The visual name of the new folder.")
@click.pass_context
def create_folder_asset(ctx, parent_id, url, object_key, display_name):
    """Create folder asset"""
    initialize_sdk(ctx)
    nomad_sdk = ctx.obj["nomad_sdk"]

    if not id and not url and not object_key:
        click.echo(json.dumps({"error": "Please provide an id, url, or object-key."}))
        sys.exit(1)

    if url or object_key:       
        parent_id = get_id_from_url(ctx, url, object_key, nomad_sdk)  

    try:
        result = nomad_sdk.create_folder_asset(parent_id, display_name)
        
        if not result:
            click.echo(json.dumps({"error": f"Parent asset with id {parent_id} not found."}))
            sys.exit(1)

        click.echo(json.dumps(result, indent=4))

    except Exception as e:
        click.echo(json.dumps({"error": f"Error creating folder asset: {e}"}))
        sys.exit(1)